# Boorunaut
Boorunaut is a taggable imagebord built in Django. Based on [Danbooru](https://github.com/r888888888/danbooru).

* [Source repository](https://github.com/Boorunaut/Boorunaut)

# Installing

```
pip install Boorunaut
boorunaut startproject mysite
```

By default, the database is set to SQLite. For production, it is recommended to change it to another one, like PostgreSQL.